from django.core.management.base import BaseCommand

from ... import app_settings
from ...cron_scheduler import get_cron_config
from ...utils import get_backend, load_extra_config


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument(
            "--config",
            action="store",
            default=None,
            help="The path to an additional django-style config file to load",
        )

    def handle(self, **options):
        # Configuration overrides
        extra_config = options["config"]
        if extra_config is not None:
            load_extra_config(extra_config)

        self.stdout.write("dqueue")
        self.stdout.write("========================")
        self.stdout.write("")
        self.stdout.write(
            "{0:<55} {1:<5} {2}".format("Queue name", "Concurrency", "Backend")
        )
        self.stdout.write("-" * 27)

        for k, v in sorted(app_settings.WORKERS.items()):
            self.stdout.write(
                " {0:<54} {1:<5} {2}".format(k, v, get_backend(k).__class__.__name__)
            )

        self.stdout.write("")
        self.stdout.write("Middleware:")
        for x in app_settings.MIDDLEWARE:
            self.stdout.write(" * {}".format(x))

        self.stdout.write("")
        self.stdout.write("Cron configuration")

        for x in get_cron_config():
            self.stdout.write("")
            for k in (
                "command",
                "command_args",
                "hours",
                "minutes",
                "queue",
                "timeout",
                "sigkill_on_stop",
            ):
                self.stdout.write("{:>20}: {}".format(k, x.get(k, "-")))
